@@ -249,6 +249,30 @@ G_GNUC_INTERNAL void _gio_marshal_OBJECT__VOID (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
+/* VOID:OBJECT,OBJECT (./gio-marshal.list:32) */
+G_GNUC_INTERNAL void _gio_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
+                                                       GValue       *return_value,
+                                                       guint         n_param_values,
+                                                       const GValue *param_values,
+                                                       gpointer      invocation_hint,
+                                                       gpointer      marshal_data);
+
+/* VOID:OBJECT,OBJECT,STRING,STRING,VARIANT (./gio-marshal.list:33) */
+G_GNUC_INTERNAL void _gio_marshal_VOID__OBJECT_OBJECT_STRING_STRING_VARIANT (GClosure     *closure,
+                                                                             GValue       *return_value,
+                                                                             guint         n_param_values,
+                                                                             const GValue *param_values,
+                                                                             gpointer      invocation_hint,
+                                                                             gpointer      marshal_data);
+
+/* VOID:OBJECT,OBJECT,VARIANT,BOXED (./gio-marshal.list:34) */
+G_GNUC_INTERNAL void _gio_marshal_VOID__OBJECT_OBJECT_VARIANT_BOXED (GClosure     *closure,
+                                                                     GValue       *return_value,
+                                                                     guint         n_param_values,
+                                                                     const GValue *param_values,
+                                                                     gpointer      invocation_hint,
+                                                                     gpointer      marshal_data);
+
 G_END_DECLS
 
 #endif /* ___gio_marshal_MARSHAL_H__ */
