@@ -240,29 +240,44 @@ gsettings_list_recursively (GSettings   *settings,
                             const gchar *key,
                             const gchar *value)
 {
-  gchar **children;
-  gint i;
-
-  enumerate (settings);
-
-  children = g_settings_list_children (settings);
-
-  for (i = 0; children[i]; i++)
+  if (settings)
     {
-      GSettings *child;
-      gchar *schema;
+      gchar **children;
+      gint i;
 
-      child = g_settings_get_child (settings, children[i]);
-      g_object_get (child, "schema", &schema, NULL);
+      enumerate (settings);
+      children = g_settings_list_children (settings);
+      for (i = 0; children[i]; i++)
+        {
+          GSettings *child;
+          gchar *schema;
 
-      if (is_schema (schema))
-        enumerate (child);
+          child = g_settings_get_child (settings, children[i]);
+          g_object_get (child, "schema", &schema, NULL);
 
-      g_object_unref (child);
-      g_free (schema);
+          if (is_schema (schema))
+            enumerate (child);
+
+          g_object_unref (child);
+          g_free (schema);
+        }
+
+      g_strfreev (children);
     }
+  else
+    {
+      const gchar * const *schemas;
+      gint i;
 
-  g_strfreev (children);
+      schemas = g_settings_list_schemas ();
+
+      for (i = 0; schemas[i]; i++)
+        {
+          settings = g_settings_new (schemas[i]);
+          enumerate (settings);
+          g_object_unref (settings);
+        }
+    }
 }
 
 static void
@@ -342,6 +357,54 @@ gsettings_reset (GSettings   *settings,
   g_settings_sync ();
 }
 
+static void
+reset_all_keys (GSettings   *settings)
+{
+  gchar **keys;
+  gint i;
+
+  keys = g_settings_list_keys (settings);
+  for (i = 0; keys[i]; i++)
+    {
+      g_settings_reset (settings, keys[i]);
+    }
+
+  g_strfreev (keys);
+}
+
+static void
+gsettings_reset_recursively (GSettings   *settings,
+			     const gchar *key,
+			     const gchar *value)
+{
+  gchar **children;
+  gint i;
+
+  g_settings_delay (settings);
+  
+  reset_all_keys (settings);
+  children = g_settings_list_children (settings);
+  for (i = 0; children[i]; i++)
+    {
+      GSettings *child;
+      gchar *schema;
+      
+      child = g_settings_get_child (settings, children[i]);
+      g_object_get (child, "schema", &schema, NULL);
+      
+      if (is_schema (schema))
+	reset_all_keys (child);
+      
+      g_object_unref (child);
+      g_free (schema);
+    }
+  
+  g_strfreev (children);
+  
+  g_settings_apply (settings);
+  g_settings_sync ();
+}
+
 static void
 gsettings_writable (GSettings   *settings,
                     const gchar *key,
@@ -394,6 +457,7 @@ gsettings_set (GSettings   *settings,
   GError *error = NULL;
   GVariant *existing;
   GVariant *new;
+  GVariant *stored;
   gchar *freeme = NULL;
 
   existing = g_settings_get_value (settings, key);
@@ -427,16 +491,23 @@ gsettings_set (GSettings   *settings,
   if (!g_settings_range_check (settings, key, new))
     {
       g_printerr (_("The provided value is outside of the valid range\n"));
-      g_variant_unref (new);
       exit (1);
     }
 
   g_settings_set_value (settings, key, new);
+  g_settings_sync ();
+
+  stored = g_settings_get_value (settings, key);
+  if (g_variant_equal (stored, existing))
+    {
+      g_printerr (_("Failed to set value\n"));
+      exit (1);
+    }
+
+  g_variant_unref (stored);
   g_variant_unref (existing);
   g_variant_unref (new);
 
-  g_settings_sync ();
-
   g_free (freeme);
 }
 
@@ -485,8 +556,9 @@ gsettings_help (gboolean     requested,
 
   else if (strcmp (command, "list-recursively") == 0)
     {
-      description = _("List keys and values, recursively");
-      synopsis = N_("SCHEMA[:PATH]");
+      description = _("List keys and values, recursively\n"
+                      "If no SCHEMA is given, list all keys\n");
+      synopsis = N_("[SCHEMA[:PATH]]");
     }
 
   else if (strcmp (command, "get") == 0)
@@ -513,6 +585,12 @@ gsettings_help (gboolean     requested,
       synopsis = N_("SCHEMA[:PATH] KEY");
     }
 
+  else if (strcmp (command, "reset-recursively") == 0)
+    {
+      description = _("Reset all keys in SCHEMA to their defaults");
+      synopsis = N_("SCHEMA[:PATH]");
+    }
+
   else if (strcmp (command, "writable") == 0)
     {
       description = _("Check if KEY is writable");
@@ -550,6 +628,7 @@ gsettings_help (gboolean     requested,
         "  get                       Get the value of a key\n"
         "  set                       Set the value of a key\n"
         "  reset                     Reset the value of a key\n"
+        "  reset-recursively         Reset all values in a given schema\n"
         "  writable                  Check if a key is writable\n"
         "  monitor                   Watch for changes\n"
         "\n"
@@ -558,7 +637,7 @@ gsettings_help (gboolean     requested,
   else
     {
       g_string_append_printf (string, _("Usage:\n  gsettings %s %s\n\n%s\n\n"),
-                              command, _(synopsis), description);
+                              command, synopsis[0] ? _(synopsis) : "", description);
 
       if (synopsis[0])
         {
@@ -592,7 +671,7 @@ gsettings_help (gboolean     requested,
   if (requested)
     g_print ("%s", string->str);
   else
-    g_printerr ("%s", string->str);
+    g_printerr ("%s\n", string->str);
 
   g_string_free (string, TRUE);
 
@@ -608,6 +687,19 @@ main (int argc, char **argv)
   const gchar *key;
 
   setlocale (LC_ALL, "");
+  textdomain (GETTEXT_PACKAGE);
+
+#ifdef G_OS_WIN32
+  gchar *tmp = _glib_get_locale_dir ();
+  bindtextdomain (GETTEXT_PACKAGE, tmp);
+  g_free (tmp);
+#else
+  bindtextdomain (GETTEXT_PACKAGE, GLIB_LOCALE_DIR);
+#endif
+
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
 
   if (argc < 2)
     return gsettings_help (FALSE, NULL);
@@ -627,7 +719,7 @@ main (int argc, char **argv)
   else if (argc == 3 && strcmp (argv[1], "list-children") == 0)
     function = gsettings_list_children;
 
-  else if (argc == 3 && strcmp (argv[1], "list-recursively") == 0)
+  else if ((argc == 2 || argc == 3) && strcmp (argv[1], "list-recursively") == 0)
     function = gsettings_list_recursively;
 
   else if (argc == 4 && strcmp (argv[1], "range") == 0)
@@ -642,6 +734,9 @@ main (int argc, char **argv)
   else if (argc == 4 && strcmp (argv[1], "reset") == 0)
     function = gsettings_reset;
 
+  else if (argc == 3 && strcmp (argv[1], "reset-recursively") == 0)
+    function = gsettings_reset_recursively;
+
   else if (argc == 4 && strcmp (argv[1], "writable") == 0)
     function = gsettings_writable;
 
@@ -659,7 +754,7 @@ main (int argc, char **argv)
 
       if (argv[2][0] == '\0')
         {
-          g_printerr (_("Empty schema name given"));
+          g_printerr (_("Empty schema name given\n"));
           return 1;
         }
 
