@@ -72,7 +72,8 @@
  *
  * To create a new #GSimpleAsyncResult, call g_simple_async_result_new().
  * If the result needs to be created for a #GError, use
- * g_simple_async_result_new_from_error(). If a #GError is not available
+ * g_simple_async_result_new_from_error() or
+ * g_simple_async_result_new_take_error(). If a #GError is not available
  * (e.g. the asynchronous operation's doesn't take a #GError argument),
  * but the result still needs to be created for an error condition, use
  * g_simple_async_result_new_error() (or g_simple_async_result_set_error_va()
@@ -186,7 +187,7 @@
  *       return;
  *     }
  *
- *   _baker_prepare_cake (self, radius, baked_cb, user_data);
+ *   _baker_prepare_cake (self, radius, baked_cb, simple);
  * }
  *
  * Cake *
@@ -298,10 +299,9 @@ g_simple_async_result_init (GSimpleAsyncResult *simple)
 
 /**
  * g_simple_async_result_new:
- * @source_object: a #GObject the asynchronous function was called with,
- * or %NULL.
- * @callback: a #GAsyncReadyCallback.
- * @user_data: user data passed to @callback.
+ * @source_object: (allow-none): a #GObject, or %NULL.
+ * @callback: (scope async): a #GAsyncReadyCallback.
+ * @user_data: (closure): user data passed to @callback.
  * @source_tag: the asynchronous function.
  *
  * Creates a #GSimpleAsyncResult.
@@ -332,10 +332,10 @@ g_simple_async_result_new (GObject             *source_object,
 
 /**
  * g_simple_async_result_new_from_error:
- * @source_object: a #GObject, or %NULL.
- * @callback: a #GAsyncReadyCallback.
- * @user_data: user data passed to @callback.
- * @error: a #GError location.
+ * @source_object: (allow-none): a #GObject, or %NULL.
+ * @callback: (scope async): a #GAsyncReadyCallback.
+ * @user_data: (closure): user data passed to @callback.
+ * @error: a #GError
  *
  * Creates a #GSimpleAsyncResult from an error condition.
  *
@@ -345,7 +345,7 @@ GSimpleAsyncResult *
 g_simple_async_result_new_from_error (GObject             *source_object,
                                       GAsyncReadyCallback  callback,
                                       gpointer             user_data,
-                                      GError              *error)
+                                      const GError        *error)
 {
   GSimpleAsyncResult *simple;
 
@@ -359,11 +359,43 @@ g_simple_async_result_new_from_error (GObject             *source_object,
   return simple;
 }
 
+/**
+ * g_simple_async_result_new_take_error: (skip)
+ * @source_object: (allow-none): a #GObject, or %NULL
+ * @callback: (scope async): a #GAsyncReadyCallback
+ * @user_data: (closure): user data passed to @callback
+ * @error: a #GError
+ *
+ * Creates a #GSimpleAsyncResult from an error condition, and takes over the
+ * caller's ownership of @error, so the caller does not need to free it anymore.
+ *
+ * Returns: a #GSimpleAsyncResult
+ *
+ * Since: 2.28
+ **/
+GSimpleAsyncResult *
+g_simple_async_result_new_take_error (GObject             *source_object,
+                                      GAsyncReadyCallback  callback,
+                                      gpointer             user_data,
+                                      GError              *error)
+{
+  GSimpleAsyncResult *simple;
+
+  g_return_val_if_fail (!source_object || G_IS_OBJECT (source_object), NULL);
+
+  simple = g_simple_async_result_new (source_object,
+				      callback,
+				      user_data, NULL);
+  g_simple_async_result_take_error (simple, error);
+
+  return simple;
+}
+
 /**
  * g_simple_async_result_new_error:
- * @source_object: a #GObject, or %NULL.
- * @callback: a #GAsyncReadyCallback.
- * @user_data: user data passed to @callback.
+ * @source_object: (allow-none): a #GObject, or %NULL.
+ * @callback: (scope async): a #GAsyncReadyCallback.
+ * @user_data: (closure): user data passed to @callback.
  * @domain: a #GQuark.
  * @code: an error code.
  * @format: a string with format characters.
@@ -439,7 +471,7 @@ g_simple_async_result_set_handle_cancellation (GSimpleAsyncResult *simple,
 }
 
 /**
- * g_simple_async_result_get_source_tag:
+ * g_simple_async_result_get_source_tag: (skip)
  * @simple: a #GSimpleAsyncResult.
  *
  * Gets the source tag for the #GSimpleAsyncResult.
@@ -456,7 +488,7 @@ g_simple_async_result_get_source_tag (GSimpleAsyncResult *simple)
 /**
  * g_simple_async_result_propagate_error:
  * @simple: a #GSimpleAsyncResult.
- * @dest: a location to propegate the error to.
+ * @dest: (out): a location to propagate the error to.
  *
  * Propagates an error from within the simple asynchronous result to
  * a given destination.
@@ -480,7 +512,7 @@ g_simple_async_result_propagate_error (GSimpleAsyncResult  *simple,
 }
 
 /**
- * g_simple_async_result_set_op_res_gpointer:
+ * g_simple_async_result_set_op_res_gpointer: (skip)
  * @simple: a #GSimpleAsyncResult.
  * @op_res: a pointer result from an asynchronous function.
  * @destroy_op_res: a #GDestroyNotify function.
@@ -500,7 +532,7 @@ g_simple_async_result_set_op_res_gpointer (GSimpleAsyncResult *simple,
 }
 
 /**
- * g_simple_async_result_get_op_res_gpointer:
+ * g_simple_async_result_get_op_res_gpointer: (skip)
  * @simple: a #GSimpleAsyncResult.
  *
  * Gets a pointer result as returned by the asynchronous function.
@@ -599,7 +631,30 @@ g_simple_async_result_set_from_error (GSimpleAsyncResult *simple,
 }
 
 /**
- * g_simple_async_result_set_error_va:
+ * g_simple_async_result_take_error: (skip)
+ * @simple: a #GSimpleAsyncResult
+ * @error: a #GError
+ *
+ * Sets the result from @error, and takes over the caller's ownership
+ * of @error, so the caller does not need to free it any more.
+ *
+ * Since: 2.28
+ **/
+void
+g_simple_async_result_take_error (GSimpleAsyncResult *simple,
+                                  GError             *error)
+{
+  g_return_if_fail (G_IS_SIMPLE_ASYNC_RESULT (simple));
+  g_return_if_fail (error != NULL);
+
+  if (simple->error)
+    g_error_free (simple->error);
+  simple->error = error;
+  simple->failed = TRUE;
+}
+
+/**
+ * g_simple_async_result_set_error_va: (skip)
  * @simple: a #GSimpleAsyncResult.
  * @domain: a #GQuark (usually #G_IO_ERROR).
  * @code: an error code.
@@ -627,7 +682,7 @@ g_simple_async_result_set_error_va (GSimpleAsyncResult *simple,
 }
 
 /**
- * g_simple_async_result_set_error:
+ * g_simple_async_result_set_error: (skip)
  * @simple: a #GSimpleAsyncResult.
  * @domain: a #GQuark (usually #G_IO_ERROR).
  * @code: an error code.
@@ -689,9 +744,13 @@ g_simple_async_result_complete (GSimpleAsyncResult *simple)
 #endif
 
   if (simple->callback)
-    simple->callback (simple->source_object,
-		      G_ASYNC_RESULT (simple),
-		      simple->user_data);
+    {
+      g_main_context_push_thread_default (simple->context);
+      simple->callback (simple->source_object,
+			G_ASYNC_RESULT (simple),
+			simple->user_data);
+      g_main_context_pop_thread_default (simple->context);
+    }
 }
 
 static gboolean
@@ -795,11 +854,11 @@ run_in_thread (GIOSchedulerJob *job,
 }
 
 /**
- * g_simple_async_result_run_in_thread:
+ * g_simple_async_result_run_in_thread: (skip)
  * @simple: a #GSimpleAsyncResult.
  * @func: a #GSimpleAsyncThreadFunc.
  * @io_priority: the io priority of the request.
- * @cancellable: optional #GCancellable object, %NULL to ignore.
+ * @cancellable: (allow-none): optional #GCancellable object, %NULL to ignore.
  *
  * Runs the asynchronous job in a separate thread and then calls
  * g_simple_async_result_complete_in_idle() on @simple to return
@@ -848,6 +907,8 @@ g_simple_async_result_run_in_thread (GSimpleAsyncResult     *simple,
  * _finish function from which this function is called).
  *
  * Returns: #TRUE if all checks passed or #FALSE if any failed.
+ *
+ * Since: 2.20
  **/
 gboolean
 g_simple_async_result_is_valid (GAsyncResult *result,
@@ -876,8 +937,8 @@ g_simple_async_result_is_valid (GAsyncResult *result,
 }
 
 /**
- * g_simple_async_report_error_in_idle:
- * @object: a #GObject.
+ * g_simple_async_report_error_in_idle: (skip)
+ * @object: (allow-none): a #GObject, or %NULL.
  * @callback: a #GAsyncReadyCallback.
  * @user_data: user data passed to @callback.
  * @domain: a #GQuark containing the error domain (usually #G_IO_ERROR).
@@ -901,7 +962,7 @@ g_simple_async_report_error_in_idle (GObject             *object,
   GSimpleAsyncResult *simple;
   va_list args;
  
-  g_return_if_fail (G_IS_OBJECT (object));
+  g_return_if_fail (!object || G_IS_OBJECT (object));
   g_return_if_fail (domain != 0);
   g_return_if_fail (format != NULL);
 
@@ -918,9 +979,9 @@ g_simple_async_report_error_in_idle (GObject             *object,
 
 /**
  * g_simple_async_report_gerror_in_idle:
- * @object: a #GObject.
- * @callback: a #GAsyncReadyCallback.
- * @user_data: user data passed to @callback.
+ * @object: (allow-none): a #GObject, or %NULL
+ * @callback: (scope async): a #GAsyncReadyCallback.
+ * @user_data: (closure): user data passed to @callback.
  * @error: the #GError to report
  *
  * Reports an error in an idle function. Similar to
@@ -931,11 +992,11 @@ void
 g_simple_async_report_gerror_in_idle (GObject *object,
 				      GAsyncReadyCallback callback,
 				      gpointer user_data,
-				      GError *error)
+				      const GError *error)
 {
   GSimpleAsyncResult *simple;
  
-  g_return_if_fail (G_IS_OBJECT (object));
+  g_return_if_fail (!object || G_IS_OBJECT (object));
   g_return_if_fail (error != NULL);
 
   simple = g_simple_async_result_new_from_error (object,
@@ -945,3 +1006,35 @@ g_simple_async_report_gerror_in_idle (GObject *object,
   g_simple_async_result_complete_in_idle (simple);
   g_object_unref (simple);
 }
+
+/**
+ * g_simple_async_report_take_gerror_in_idle: (skip)
+ * @object: (allow-none): a #GObject, or %NULL
+ * @callback: a #GAsyncReadyCallback.
+ * @user_data: user data passed to @callback.
+ * @error: the #GError to report
+ *
+ * Reports an error in an idle function. Similar to
+ * g_simple_async_report_gerror_in_idle(), but takes over the caller's
+ * ownership of @error, so the caller does not have to free it any more.
+ *
+ * Since: 2.28
+ **/
+void
+g_simple_async_report_take_gerror_in_idle (GObject *object,
+                                           GAsyncReadyCallback callback,
+                                           gpointer user_data,
+                                           GError *error)
+{
+  GSimpleAsyncResult *simple;
+
+  g_return_if_fail (!object || G_IS_OBJECT (object));
+  g_return_if_fail (error != NULL);
+
+  simple = g_simple_async_result_new_take_error (object,
+                                                 callback,
+                                                 user_data,
+                                                 error);
+  g_simple_async_result_complete_in_idle (simple);
+  g_object_unref (simple);
+}
