@@ -156,6 +156,7 @@ GAsyncQueue *
 g_async_queue_ref (GAsyncQueue *queue)
 {
   g_return_val_if_fail (queue, NULL);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
   
   g_atomic_int_inc (&queue->ref_count);
 
@@ -176,6 +177,7 @@ void
 g_async_queue_ref_unlocked (GAsyncQueue *queue)
 {
   g_return_if_fail (queue);
+  g_return_if_fail (g_atomic_int_get (&queue->ref_count) > 0);
   
   g_atomic_int_inc (&queue->ref_count);
 }
@@ -197,6 +199,7 @@ void
 g_async_queue_unref_and_unlock (GAsyncQueue *queue)
 {
   g_return_if_fail (queue);
+  g_return_if_fail (g_atomic_int_get (&queue->ref_count) > 0);
 
   g_mutex_unlock (queue->mutex);
   g_async_queue_unref (queue);
@@ -216,6 +219,7 @@ void
 g_async_queue_unref (GAsyncQueue *queue)
 {
   g_return_if_fail (queue);
+  g_return_if_fail (g_atomic_int_get (&queue->ref_count) > 0);
   
   if (g_atomic_int_dec_and_test (&queue->ref_count))
     {
@@ -242,6 +246,7 @@ void
 g_async_queue_lock (GAsyncQueue *queue)
 {
   g_return_if_fail (queue);
+  g_return_if_fail (g_atomic_int_get (&queue->ref_count) > 0);
 
   g_mutex_lock (queue->mutex);
 }
@@ -256,6 +261,7 @@ void
 g_async_queue_unlock (GAsyncQueue *queue)
 {
   g_return_if_fail (queue);
+  g_return_if_fail (g_atomic_int_get (&queue->ref_count) > 0);
 
   g_mutex_unlock (queue->mutex);
 }
@@ -271,6 +277,7 @@ void
 g_async_queue_push (GAsyncQueue* queue, gpointer data)
 {
   g_return_if_fail (queue);
+  g_return_if_fail (g_atomic_int_get (&queue->ref_count) > 0);
   g_return_if_fail (data);
 
   g_mutex_lock (queue->mutex);
@@ -290,6 +297,7 @@ void
 g_async_queue_push_unlocked (GAsyncQueue* queue, gpointer data)
 {
   g_return_if_fail (queue);
+  g_return_if_fail (g_atomic_int_get (&queue->ref_count) > 0);
   g_return_if_fail (data);
 
   g_queue_push_head (&queue->queue, data);
@@ -442,6 +450,7 @@ g_async_queue_pop (GAsyncQueue* queue)
   gpointer retval;
 
   g_return_val_if_fail (queue, NULL);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
 
   g_mutex_lock (queue->mutex);
   retval = g_async_queue_pop_intern_unlocked (queue, FALSE, NULL);
@@ -464,6 +473,7 @@ gpointer
 g_async_queue_pop_unlocked (GAsyncQueue* queue)
 {
   g_return_val_if_fail (queue, NULL);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
 
   return g_async_queue_pop_intern_unlocked (queue, FALSE, NULL);
 }
@@ -484,6 +494,7 @@ g_async_queue_try_pop (GAsyncQueue* queue)
   gpointer retval;
 
   g_return_val_if_fail (queue, NULL);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
 
   g_mutex_lock (queue->mutex);
   retval = g_async_queue_pop_intern_unlocked (queue, TRUE, NULL);
@@ -507,6 +518,7 @@ gpointer
 g_async_queue_try_pop_unlocked (GAsyncQueue* queue)
 {
   g_return_val_if_fail (queue, NULL);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
 
   return g_async_queue_pop_intern_unlocked (queue, TRUE, NULL);
 }
@@ -531,6 +543,7 @@ g_async_queue_timed_pop (GAsyncQueue* queue, GTimeVal *end_time)
   gpointer retval;
 
   g_return_val_if_fail (queue, NULL);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
 
   g_mutex_lock (queue->mutex);
   retval = g_async_queue_pop_intern_unlocked (queue, FALSE, end_time);
@@ -558,6 +571,7 @@ gpointer
 g_async_queue_timed_pop_unlocked (GAsyncQueue* queue, GTimeVal *end_time)
 {
   g_return_val_if_fail (queue, NULL);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
 
   return g_async_queue_pop_intern_unlocked (queue, FALSE, end_time);
 }
@@ -582,6 +596,7 @@ g_async_queue_length (GAsyncQueue* queue)
   gint retval;
 
   g_return_val_if_fail (queue, 0);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, 0);
 
   g_mutex_lock (queue->mutex);
   retval = queue->queue.length - queue->waiting_threads;
@@ -609,6 +624,7 @@ gint
 g_async_queue_length_unlocked (GAsyncQueue* queue)
 {
   g_return_val_if_fail (queue, 0);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, 0);
 
   return queue->queue.length - queue->waiting_threads;
 }
@@ -699,6 +715,7 @@ GMutex*
 _g_async_queue_get_mutex (GAsyncQueue* queue)
 {
   g_return_val_if_fail (queue, NULL);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
 
   return queue->mutex;
 }
