@@ -851,6 +851,7 @@ g_utf8_to_ucs4_fast (const gchar *str,
 		     glong        len,              
 		     glong       *items_written)    
 {
+  gint j, charlen;
   gunichar *result;
   gint n_chars, i;
   const gchar *p;
@@ -881,37 +882,49 @@ g_utf8_to_ucs4_fast (const gchar *str,
   p = str;
   for (i=0; i < n_chars; i++)
     {
-      gunichar wc = (guchar)*p++;
+      gunichar wc = ((unsigned char *)p)[0];
 
       if (wc < 0x80)
 	{
 	  result[i] = wc;
+	  p++;
 	}
       else
 	{ 
-	  gunichar mask = 0x40;
-
-	  if (G_UNLIKELY ((wc & mask) == 0))
+	  if (wc < 0xe0)
 	    {
-	      /* It's an out-of-sequence 10xxxxxxx byte.
-	       * Rather than making an ugly hash of this and the next byte
-	       * and overrunning the buffer, it's more useful to treat it
-	       * with a replacement character */
-	      result[i] = 0xfffd;
-	      continue;
+	      charlen = 2;
+	      wc &= 0x1f;
+	    }
+	  else if (wc < 0xf0)
+	    {
+	      charlen = 3;
+	      wc &= 0x0f;
+	    }
+	  else if (wc < 0xf8)
+	    {
+	      charlen = 4;
+	      wc &= 0x07;
+	    }
+	  else if (wc < 0xfc)
+	    {
+	      charlen = 5;
+	      wc &= 0x03;
+	    }
+	  else
+	    {
+	      charlen = 6;
+	      wc &= 0x01;
 	    }
 
-	  do
+	  for (j = 1; j < charlen; j++)
 	    {
 	      wc <<= 6;
-	      wc |= (guchar)(*p++) & 0x3f;
-	      mask <<= 5;
+	      wc |= ((unsigned char *)p)[j] & 0x3f;
 	    }
-	  while((wc & mask) != 0);
-
-	  wc &= mask - 1;
 
 	  result[i] = wc;
+	  p += charlen;
 	}
     }
   result[i] = 0;
@@ -1279,13 +1292,11 @@ g_utf16_to_ucs4 (const gunichar2  *str,
   while ((len < 0 || in - str < len) && *in)
     {
       gunichar2 c = *in;
-      gunichar wc;
 
       if (c >= 0xdc00 && c < 0xe000) /* low surrogate */
 	{
 	  if (high_surrogate)
 	    {
-	      wc = SURROGATE_VALUE (high_surrogate, c);
 	      high_surrogate = 0;
 	    }
 	  else
@@ -1309,8 +1320,6 @@ g_utf16_to_ucs4 (const gunichar2  *str,
 	      high_surrogate = c;
 	      goto next1;
 	    }
-	  else
-	    wc = c;
 	}
 
       /********** DIFFERENT for UTF8/UCS4 **********/
